@@ -659,7 +659,7 @@ $SET_DEBCONF_OVERRIDE
 
 [ -x /usr/sbin/locale-gen ] && /usr/sbin/locale-gen
 
-dselect update
+apt-get update
 
 if [ ! -f /etc/timezone ]; then
     # tzsetup was part of base-config which is gone since etch
